@@ -146,14 +146,14 @@ THEORY_LEVELS = {
         "ccsdt",
         "qcisd",
         "qcisdt",
-        "lpno-ccsd",
-        "lpno-ccsdt",
-        "lpno-qcisd",
-        "lpno-qcisdt",
-        "dlpno-ccsd",
-        "dlpno-ccsdt",
-        "dlpno-qcisd",
-        "dlpno-qcisdt",
+        "lpnoccsd",
+        "lpnoccsdt",
+        "lpnoqcisd",
+        "lpnoqcisdt",
+        "dlpnoccsd",
+        "dlpnoccsdt",
+        "dlpnoqcisd",
+        "dlpnoqcisdt",
     ],
     # Everything else is assumed to be DFT, because it most likely is
 }
@@ -2201,7 +2201,7 @@ SOFTWARE_SOLVENTS = {
         "ammonia": "ammonia",
         "benzene": "benzene",
         "carbontetrachloride": "ccl4",
-        "dichloromethane": "ch2cl2",
+        "dichloromethane": "dcm",
         "chloroform": "chloroform",
         "cyclohexane": "cyclohexane",
         "dimethylformamide": "dmf",
