@@ -453,13 +453,169 @@ class OrcaTests(InputTests):
             "method": "RI-MP2",
             "basis_set": "cc-pVTZ",
             "charge": "-1",
+            "specifications": "cc-pvtz/C",
+        }
+
+        inp = self.generate_calculation(**params)
+
+        REF = """
+        !SP RI-MP2 cc-pVTZ cc-pVTZ/C
+        *xyz -1 1
+        Cl 0.0 0.0 0.0
+        *
+        %pal
+        nprocs 8
+        end
+        """
+
+        self.assertTrue(self.is_equivalent(REF, inp.input_file))
+
+    def test_sp_MP2_default_aux(self):
+        params = {
+            "nproc": 8,
+            "type": "Single-Point Energy",
+            "file": "Cl.xyz",
+            "software": "ORCA",
+            "method": "RI-MP2",
+            "basis_set": "cc-pVTZ",
+            "charge": "-1",
+            "specifications": "",
+        }
+
+        inp = self.generate_calculation(**params)
+
+        REF = """
+        !SP RI-MP2 cc-pVTZ cc-pVTZ/C
+        *xyz -1 1
+        Cl 0.0 0.0 0.0
+        *
+        %pal
+        nprocs 8
+        end
+        """
+
+        self.assertTrue(self.is_equivalent(REF, inp.input_file))
+
+    def test_sp_MP2_override_aux(self):
+        params = {
+            "nproc": 8,
+            "type": "Single-Point Energy",
+            "file": "Cl.xyz",
+            "software": "ORCA",
+            "method": "RI-MP2",
+            "basis_set": "cc-pVTZ",
+            "charge": "-1",
+            "specifications": "cc-pVDZ/C",
+        }
+
+        inp = self.generate_calculation(**params)
+
+        REF = """
+        !SP RI-MP2 cc-pVTZ cc-pVDZ/C
+        *xyz -1 1
+        Cl 0.0 0.0 0.0
+        *
+        %pal
+        nprocs 8
+        end
+        """
+
+        self.assertTrue(self.is_equivalent(REF, inp.input_file))
+
+    def test_sp_MP2_without_RI(self):
+        params = {
+            "nproc": 8,
+            "type": "Single-Point Energy",
+            "file": "Cl.xyz",
+            "software": "ORCA",
+            "method": "MP2",
+            "basis_set": "cc-pVTZ",
+            "charge": "-1",
+            "specifications": "",
+        }
+
+        inp = self.generate_calculation(**params)
+
+        REF = """
+        !SP MP2 cc-pVTZ
+        *xyz -1 1
+        Cl 0.0 0.0 0.0
+        *
+        %pal
+        nprocs 8
+        end
+        """
+
+        self.assertTrue(self.is_equivalent(REF, inp.input_file))
+
+    def test_sp_DLPNO_CCSDT(self):
+        params = {
+            "nproc": 8,
+            "type": "Single-Point Energy",
+            "file": "Cl.xyz",
+            "software": "ORCA",
+            "method": "DLPNO-CCSD(T)",
+            "basis_set": "cc-pVTZ",
+            "charge": "-1",
             "specifications": "cc-pVTZ/C",
         }
 
         inp = self.generate_calculation(**params)
 
         REF = """
-        !SP RI-MP2 cc-pVTZ cc-pvtz/c
+        !SP DLPNO-CCSD(T) cc-pVTZ cc-pVTZ/C
+        *xyz -1 1
+        Cl 0.0 0.0 0.0
+        *
+        %pal
+        nprocs 8
+        end
+        """
+
+        self.assertTrue(self.is_equivalent(REF, inp.input_file))
+
+    def test_sp_DLPNO_CCSDT_default_aux(self):
+        params = {
+            "nproc": 8,
+            "type": "Single-Point Energy",
+            "file": "Cl.xyz",
+            "software": "ORCA",
+            "method": "DLPNO-CCSD(T)",
+            "basis_set": "cc-pVTZ",
+            "charge": "-1",
+            "specifications": "",
+        }
+
+        inp = self.generate_calculation(**params)
+
+        REF = """
+        !SP DLPNO-CCSD(T) cc-pVTZ cc-pVTZ/C
+        *xyz -1 1
+        Cl 0.0 0.0 0.0
+        *
+        %pal
+        nprocs 8
+        end
+        """
+
+        self.assertTrue(self.is_equivalent(REF, inp.input_file))
+
+    def test_sp_CCSDT(self):
+        params = {
+            "nproc": 8,
+            "type": "Single-Point Energy",
+            "file": "Cl.xyz",
+            "software": "ORCA",
+            "method": "CCSD(T)",
+            "basis_set": "cc-pVTZ",
+            "charge": "-1",
+            "specifications": "",
+        }
+
+        inp = self.generate_calculation(**params)
+
+        REF = """
+        !SP CCSD(T) cc-pVTZ
         *xyz -1 1
         Cl 0.0 0.0 0.0
         *
@@ -658,6 +814,44 @@ class OrcaTests(InputTests):
 
         self.assertTrue(self.is_equivalent(REF, inp.input_file))
 
+    def test_scan_bond_DFT_auto(self):
+        params = {
+            "nproc": 8,
+            "type": "Constrained Optimisation",
+            "file": "ethanol.xyz",
+            "software": "ORCA",
+            "charge": "0",
+            "method": "B3LYP",
+            "basis_set": "6-31+G(d,p)",
+            "constraints": "Scan_auto_1.4_10/1_2;",
+        }
+
+        inp = self.generate_calculation(**params)
+
+        REF = """
+        !OPT B3LYP 6-31+G(d,p)
+        *xyz 0 1
+        C         -1.31970       -0.64380        0.00000
+        H         -0.96310       -1.65260        0.00000
+        H         -0.96310       -0.13940       -0.87370
+        H         -2.38970       -0.64380        0.00000
+        C         -0.80640        0.08220        1.25740
+        H         -1.16150        1.09160        1.25640
+        H         -1.16470       -0.42110        2.13110
+        O          0.62360        0.07990        1.25870
+        H          0.94410        0.53240        2.04240
+        *
+        %geom Scan
+        B 0 1 = 1.07, 1.40, 10
+        end
+        end
+        %pal
+        nprocs 8
+        end
+        """
+
+        self.assertTrue(self.is_equivalent(REF, inp.input_file))
+
     def test_invalid_opt_mod(self):
         params = {
             "nproc": 8,
